import numpy as np





# Measure the normalized lag between forcing (F) and a response (R). F and R are both vectors of size N
def Dephasage(F,R):
    phiF = np.where(F == max(F))
    phiR = np.where(R == max(R))
    return abs(np.subtract(phiR,phiF))/(len(F)*1.0);


# Measure the normalized amplitude between forcing (F) and a response (R). F and R are both vectors of the same size 
def Amplitude(F,R):
    AF = max(F)-min(F)
    AR = max(R)-min(R)
    return AR/AF;


# Measure dimensionless energy flux
def Flux(T, Nr, Nk, T01, Xr):
    Tu1 = Xr[0:T]
    Tu2 = Xr[T:2*T]
    Tb1 = Xr[2*T:3*T]
    q = (T01 - Tu1) + Nr*(Tb1 - Tu1)/Nk 
    q += [0.5*T*Nr*(Tu1[(t-1)%T]-Tu1[(t+1)%T])   for t in np.arange(0,T,1)]
    return q;


# Measure mixing coefficient m
def MixingCoeff(T, Nr, Nk, T01, Xr):
    Tu1 = Xr[0:T]
    Tu2 = Xr[T:2*T]
    Tb1 = Xr[2*T:3*T]
    q = (T01 - Tu1) + Nr*(Tb1 - Tu1)/Nk 
    q += [0.5*T*Nr*(Tu1[(t-1)%T]-Tu1[(t+1)%T])   for t in np.arange(0,T,1)]
    m = q/(Tu1-Tu2) 
    return m;



# Measure entropy production
def Sigma(T, Nr, Nk, T01, Xr):
    Tu1 = Xr[0:T]
    Tu2 = Xr[T:2*T]
    Tb1 = Xr[2*T:3*T]
    q = (T01 - Tu1) + Nr*(Tb1 - Tu1)/Nk 
    q += [0.5*T*Nr*(Tu1[(t-1)%T]-Tu1[(t+1)%T])   for t in np.arange(0,T,1)]
    sig = q*(1.0/Tu1-1.0/Tu2) 
    return m;



 







